==> atmos-2.96.7.tar.gz: atmos-2.96.7/src/dimm.cpp <==
/*
    $Id: dimm.cpp 115 2010-03-14 08:48:08Z matwey $
    Copyright (C) 2010  Sternberg Astronomical Institute, MSU

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <cmath>

#include <boost/bind.hpp>

#include "dimm.h"

dimm::dimm_vars_type dimm::correction( const dimm_vars_type& vars ) {
	dimm_vars_type ret( vars );

	ret(1) = ret(1)*ret(1) - ret(3)*ret(3); // CCD noise removal
	value_type rho = ret(2)/ret(1);
	ret(1) = 1.15*ret(1) - 0.15*ret(2); // exposure correction
	ret(2) = rho;
	
	return ret;
}

dimm::value_type dimm::turbulence( value_type scale, value_type Knumber, value_type variance ) {
	value_type ret = variance;
	ret *= scale * scale / 16.7 / Knumber;
	return ret;
}

dimm::value_type dimm::seeing( value_type turbulence_power ) {
	value_type ret = 2.0e7 * std::pow( turbulence_power, 0.6 );
	return ret;
}

const dimm::dimm_flux_type& dimm::left_flux( const dimm_sample& x ) {
	return x.left_flux;
}
const dimm::dimm_flux_type& dimm::right_flux( const dimm_sample& x ) {
	return x.right_flux;
}
const dimm::dimm_vars_type& dimm::xvars( const dimm_sample& x ) {
	return x.xvars;
}
const dimm::dimm_vars_type& dimm::yvars( const dimm_sample& x ) {
	return x.yvars;
}

dimm_storage::dimm_storage( size_type reserve ):
	table_storage< dimm::dimm_sample >( reserve ),
	m_left_flux_column( *this, boost::bind(&dimm::left_flux,_1) ),
	m_right_flux_column( *this, boost::bind(&dimm::right_flux,_1) ),
	m_xvars_column( *this, boost::bind(&dimm::xvars,_1) ),
	m_yvars_column( *this, boost::bind(&dimm::yvars,_1) )
	{
}

void dimm_storage::correct_low_vars( ) {
	double meanx = 0;
	double meany = 0;
	for( const_iterator it = begin(); it != end(); ++it ) {
		meanx += it->xvars(0) / size();
		meany += it->yvars(0) / size();
	}
	for( iterator it = begin(); it != end(); ++it ) {
		it->xvars(1) += ( it->xvars(0) - meanx ) * ( it->xvars(0) - meanx );
		it->yvars(1) += ( it->yvars(0) - meany ) * ( it->yvars(0) - meany );
	}
}

==> atmos-2.97.12.tar.gz: atmos-2.97.12/src/dimm.cpp <==
/*
    $Id: dimm.cpp 327 2024-10-30 12:29:33Z matwey $
    Copyright (C) 2010  Sternberg Astronomical Institute, MSU

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <cmath>
#include <functional>

#include "dimm.h"

namespace atmos {
namespace dimm {

vars_type correction( const vars_type& vars ) {
	vars_type ret( vars );

	ret(1) = ret(1)*ret(1) - ret(3)*ret(3); // CCD noise removal
	value_type rho = ret(2)/ret(1);
	ret(1) = 1.15*ret(1) - 0.15*ret(2); // exposure correction
	ret(2) = rho;
	
	return ret;
}

value_type turbulence( value_type scale, value_type Knumber, value_type variance ) {
	value_type ret = variance;
	ret *= scale * scale / 16.7 / Knumber;
	return ret;
}

value_type seeing( value_type turbulence_power ) {
	value_type ret = 2.0e7 * std::pow( turbulence_power, 0.6 );
	return ret;
}

storage::storage( size_type reserve ):
	table_storage< detail::sample >( reserve ),
	m_left_flux_column( *this, std::mem_fn(&detail::sample::left_flux) ),
	m_right_flux_column( *this, std::mem_fn(&detail::sample::right_flux) ),
	m_xvars_column( *this, std::mem_fn(&detail::sample::xvars) ),
	m_yvars_column( *this, std::mem_fn(&detail::sample::yvars) )
	{
}

}}
